@@ -22,7 +22,9 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <ayatana/common/utils.h>
-
+#ifdef RDA_ENABLED
+#  include <rda/rda.h>
+#endif /* RDA_ENABLED */
 #include "backend.h"
 #include "recoverable-problem.h"
 #include "service.h"
@@ -115,6 +117,7 @@ struct _IndicatorSessionServicePrivate
   GDBusConnection * conn;
   GCancellable * cancellable;
   GVariant * default_icon_serialized;
+  gboolean bLocal;
 };
 
 typedef IndicatorSessionServicePrivate priv_t;
@@ -676,6 +679,11 @@ create_switch_section (IndicatorSessionService * self, int profile)
 
   menu = g_menu_new ();
 
+  if (!self->priv->bLocal)
+  {
+      return G_MENU_MODEL (menu);
+  }
+
   /* lockswitch */
   if (indicator_session_users_is_live_session (p->backend_users))
     {
@@ -828,11 +836,21 @@ create_logout_section (IndicatorSessionService * self)
 
   menu = g_menu_new ();
 
-  if (indicator_session_actions_can_logout (p->backend_actions))
-    {
-      const char * label = ellipsis ? _("Log Out…") : _("Log Out");
-      g_menu_append (menu, label, "indicator.logout");
-    }
+  if (!self->priv->bLocal || indicator_session_actions_can_logout (p->backend_actions))
+  {
+        const char * label = NULL;
+
+        if (self->priv->bLocal && ellipsis)
+        {
+            label = _("Log Out…");
+        }
+        else
+        {
+            label = _("Log Out");
+        }
+
+        g_menu_append (menu, label, "indicator.logout");
+  }
 
   return G_MENU_MODEL (menu);
 }
@@ -847,25 +865,39 @@ create_session_section (IndicatorSessionService * self, int profile)
 
   menu = g_menu_new ();
 
-  if (indicator_session_actions_can_suspend (p->backend_actions))
-    g_menu_append (menu, _("Suspend"), "indicator.suspend");
+  if (self->priv->bLocal)
+  {
+        if (indicator_session_actions_can_suspend (p->backend_actions))
+            g_menu_append (menu, _("Suspend"), "indicator.suspend");
 
-  if (indicator_session_actions_can_hibernate (p->backend_actions))
-    g_menu_append (menu, _("Hibernate"), "indicator.hibernate");
+        if (indicator_session_actions_can_hibernate (p->backend_actions))
+            g_menu_append (menu, _("Hibernate"), "indicator.hibernate");
 
-  if (profile != PROFILE_LOCKSCREEN &&
-    indicator_session_actions_can_reboot (p->backend_actions))
-    {
-      const char * label = ellipsis ? _("Restart…") : _("Restart");
-      g_menu_append (menu, label, "indicator.reboot");
-    }
+        if (profile != PROFILE_LOCKSCREEN && indicator_session_actions_can_reboot (p->backend_actions))
+        {
+            const char * label = ellipsis ? _("Restart…") : _("Restart");
+            g_menu_append (menu, label, "indicator.reboot");
+        }
 
-  if (profile != PROFILE_LOCKSCREEN &&
-    !g_settings_get_boolean (s, "suppress-shutdown-menuitem"))
-    {
-      const char * label = ellipsis ? _("Shut Down…") : _("Shut Down");
-      g_menu_append (menu, label, "indicator.power-off");
-    }
+        if (profile != PROFILE_LOCKSCREEN && !g_settings_get_boolean (s, "suppress-shutdown-menuitem"))
+        {
+            const char * label = ellipsis ? _("Shut Down…") : _("Shut Down");
+            g_menu_append (menu, label, "indicator.power-off");
+        }
+  }
+  else
+  {
+#ifdef RDA_ENABLED
+        gboolean bSuspendable = rda_session_can_be_suspended ();
+
+        if (bSuspendable)
+        {
+            gchar *suspend_remote = g_strdup_printf (_("Suspend %s Session"), rda_get_remote_technology_name());
+            g_menu_append (menu, suspend_remote, "indicator.remotesuspend");
+            free (suspend_remote);
+        }
+#endif
+  }
 
   return G_MENU_MODEL (menu);
 }
@@ -986,7 +1018,18 @@ on_logout_activated (GSimpleAction * a      G_GNUC_UNUSED,
                      GVariant      * param  G_GNUC_UNUSED,
                      gpointer        gself)
 {
-  indicator_session_actions_logout (get_backend_actions(gself));
+    IndicatorSessionService *self = INDICATOR_SESSION_SERVICE (gself);
+
+    if (!self->priv->bLocal)
+    {
+#ifdef RDA_ENABLED
+        rda_session_terminate ();
+#endif /* RDA_ENABLED */
+    }
+    else
+    {
+        indicator_session_actions_logout (get_backend_actions(gself));
+    }
 }
 
 static void
@@ -1062,6 +1105,13 @@ static void on_custom_activated (GSimpleAction *pAction G_GNUC_UNUSED, GVariant
     ayatana_common_utils_open_url (sUri);
 }
 
+static void on_remote_suspend (GSimpleAction *pAction G_GNUC_UNUSED, GVariant *pParam G_GNUC_UNUSED, gpointer pUserData)
+{
+#ifdef RDA_ENABLED
+    rda_session_suspend ();
+#endif /* RDA_ENABLED */
+}
+
 static void
 init_gactions (IndicatorSessionService * self)
 {
@@ -1083,7 +1133,8 @@ init_gactions (IndicatorSessionService * self)
     { "switch-to-greeter",      on_greeter_activated         },
     { "suspend",                on_suspend_activated         },
     { "power-off",              on_power_off_activated       },
-    { "custom",                 on_custom_activated          }
+    { "custom",                 on_custom_activated          },
+    { "remotesuspend",          on_remote_suspend            }
   };
 
   p->actions = g_simple_action_group_new ();
@@ -1372,6 +1423,11 @@ indicator_session_service_init (IndicatorSessionService * self)
     }
 
   self->priv = p;
+#if RDA_ENABLED
+  self->priv->bLocal = !rda_session_is_remote ();
+#else
+  self->priv->bLocal = TRUE;
+#endif /* RDA_ENABLED */
 
   /* init the backend objects */
   p->cancellable = g_cancellable_new ();
